.. :changelog:

History
-------

0.1.4 (2017-01-07)
++++++++++++++++++

* OIDC library was updated. Its version is no longer "latest" to avoid breaking django-oidc on each major library update.
* code that was broken by the update was fixed.
* no more need for wheels on Windows.

0.1.0 (2015-05-08)
++++++++++++++++++

* First release
